SimpleMessage Packets - Poweron, Discovery and Connecting
=========================================================

.. automodule:: xbox.sg.packet.simple
    :members:
    :undoc-members:
    :show-inheritance:
